@@ -48,7 +48,7 @@ from .utils import (  # type: ignore
     TagHandling,
 )
 
-__version__ = "1.5.0"
+__version__ = "1.6.0"
 
 
 class DataDriver:
@@ -765,8 +765,8 @@ class DataDriver:
     Documentation: https://github.com/Microsoft/pict/blob/master/doc/pict.md
 
 
-    Requirements
-    ^^^^^^^^^^^^
+    Requirements of PICT
+    ^^^^^^^^^^^^^^^^^^^^
 
     -  Path to pict.exe must be set in the %PATH% environment variable.
     -  Data model file has the file extention ".pict"
@@ -787,6 +787,13 @@ class DataDriver:
         *** Settings ***
         Library    DataDriver    my_model_file.pict
 
+    It is possible to give options to pict with the import argument `pict_options=`.
+
+    .. code :: robotframework
+
+        *** Settings ***
+        Library    DataDriver    pict_arg.pict    pict_options=/o:3 /r
+
 
     Glob File Pattern
     ~~~~~~~~~~~~~~~~~
@@ -1805,9 +1812,10 @@ When DataDriver is used together with Pabot, it optimizes the ``--testlevelsplit
 
     def _add_test_list_to_pabot_queue(self, pabotlib, test_list):
         test_names = [f"{self.suite_name}.{test.name}" for test in test_list]
+        pabot_string = '|'.join([name.replace('\\', '\\\\').replace('|', '\\|') for name in test_names])
         pabotlib.run_keyword(
             "add_suite_to_execution_queue",
-            [self.suite_name, [f"DYNAMICTESTS:{'|'.join(test_names)}"]],
+            [self.suite_name, [f"DYNAMICTESTS:{pabot_string}"]],
             {},
         )
 
